==> yanmah2-0.1-noarch.zip: index.php <==
<?php
//YANMAH2 - Yet ANother Mobile Accelerated HatenaHaiku
//(c) 2009 YANMAH2 project
//This program is freesoftware. you can redistribute it and/ormodify it under the terms of the [GNU Affero GPL v3](http://www.gnu.org/licenses/agpl.html).
?>
<?php echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"; ?>
<?php
define("HELLO","world");
require_once "configurable_variables.php";
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja" lang="ja">
<head>
	<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
	<meta http-equiv="Content-Style-Type" content="text/css" />
	<?php echo "<title>{$site_name}</title>\n"; ?>
	<link rel="stylesheet" href="./found.css" />
</head>
<body>
<?php
echo "<h1>{$site_name}</h1>\n";
echo "<p>by <abbr title=\"{$product_name_full}\">{$product_name_abbr}</abbr> Ver.{$product_version}</p>\n";
?>
<h2>エントリー一覧</h2>
<ul>
<li><a href="./entries.php">みんなの最新エントリー</a></li>
</ul>

<h2>ユーザーのページ</h2>
<ul>
<li><form method="get" action="./entries.php">
<label for="username">id:</label><input type="text" name="user" size="32" maxlength="32" id="username"/><label for="username">のエントリ一覧を</label><input type="submit" value="表示" />
</form></li>
<li><form method="get" action="./entries.php">
<label for="username">id:</label><input type="text" name="following" size="32" maxlength="32" id="userflw"/><label for="userflw">のアンテナを</label><input type="submit" value="表示" />
</form></li>
</ul>
<h2>注目のキーワード</h2>
<ul>
<?php
require_once "HTTP/Request.php";
$request_url = "http://h.hatena.ne.jp/api/keywords/hot.json";
$req =& new HTTP_Request($request_url);

if (!PEAR::isError($req->sendRequest())) {
	$json = $req->getResponseBody();
	$contents = json_decode($json,true);
	if (is_array($contents)){
	}	else {
			echo "<blockquote>{$json}</blockquote>";
			exit();
		}
//	echo "<pre>"; var_dump($contents); echo "</pre>";
	foreach ($contents as $val){
		echo "<li><a href=\"./entries.php?keyword=";
		echo rawurlencode($val["title"]);
		echo "\">";
		echo htmlspecialchars($val["title"], ENT_QUOTES);
		echo "</a></li>";
	}
}
?>
</ul>
<hr />
<address>
<?php
echo "はてなハイク(c)<a href=\"http://mobile.hatena.ne.jp/\">はてな</a><br />";
echo "{$product_name_abbr} PHP script (c)<a href=\"{$mobile_gateway}{$project_url}\">{$project_name}</a><br />";
echo "設置者:<a href=\"{$mobile_gateway}{$admin_url}\">$admin_name</a><br />";
echo "<a href=\"./about.php\">YANMAH2 について</a>";
?>
</address>
</body>
</html>

==> yanmah2-0.3-noarch.zip: index.php <==
<?php
//YANMAH2 - Yet ANother Mobile Accelerated HatenaHaiku
//(c) 2009 YANMAH2 project
//This program is freesoftware. you can redistribute it and/ormodify it under the terms of the [GNU Affero GPL v3](http://www.gnu.org/licenses/agpl.html).
?>
<?php echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"; ?>
<?php
define("HELLO","world");
require_once "configurable_variables.php";
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja" lang="ja">
<head>
	<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
	<meta http-equiv="Content-Style-Type" content="text/css" />
	<meta http-equiv="Content-Script-Type" content="text/javascript" />
	<?php echo "<title>{$site_name}</title>\n"; ?>
	<link rel="stylesheet" href="./found.css" />
</head>
<body>
<div id="header">
<?php
echo "<h1 id=\"index-head\" class=\"head1\">{$site_name}</h1>\n";
echo "<p class=\"caption\">by <abbr title=\"{$product_name_full}\">{$product_name_abbr}</abbr> Ver.{$product_version}</p>\n";
?>
</div>
<div id="index-contents" class="contents">
<div class="index-content content">
<h2 id="entries-index-head">エントリー一覧</h2>
<ul>
<li><a href="./entries.php">みんなの最新エントリー</a></li>
</ul>
</div>

<div class="index-content">
<h2 id="users-index-head">ユーザーのページ</h2>
<ul>
<li><form method="get" action="./entries.php">
<label for="username">id:</label><input type="text" name="user" size="32" maxlength="32" id="username"/><label for="username">のエントリを</label><input type="submit" value="表示" />
</form></li>
<li><form method="get" action="./entries.php">
<label for="username">id:</label><input type="text" name="following" size="32" maxlength="32" id="userflw"/><label for="userflw">のアンテナを</label><input type="submit" value="表示" />
</form></li>
</ul>
</div>

<div class="index-content">
<h2 id="keywords-index-head">キーワード</h2>
<ul>
<li><form method="get" action="./entries.php">
<label for="go2keyword">キーワード</label><input type="text" name="keyword" size="32" maxlength="170" id="go2keyword" /><label for="go2keyword">を</label>
<input type="submit" value="表示" />
</form></li>
<?php
require_once "HTTP/Request.php";
$request_url = "http://h.hatena.ne.jp/api/keywords/hot.json";
$req =& new HTTP_Request($request_url);

if (!PEAR::isError($req->sendRequest())) {
	$json = $req->getResponseBody();
	$contents = json_decode($json,true);
	if (is_array($contents)){
	}	else {
			echo "<blockquote>{$json}</blockquote>";
			exit();
		}
//	echo "<pre>"; var_dump($contents); echo "</pre>";
	foreach ($contents as $val){
		echo "<li><a href=\"./entries.php?keyword=";
		echo rawurlencode($val["title"]);
		echo "\" class=\"keyword\">";
		echo htmlspecialchars($val["title"], ENT_QUOTES);
		echo "</a></li>";
	}
}
?>
</ul>
</div>
</div>
<hr />
<div id="footer">
<address>
<?php
echo "はてなハイク(c)<a href=\"http://mobile.hatena.ne.jp/\">はてな</a><br />";
echo "{$product_name_abbr} PHP script (c)<a href=\"{$mobile_gateway}{$project_url}\">{$project_name}</a><br />";
echo "設置者:<a href=\"{$mobile_gateway}{$admin_url}\">$admin_name</a><br />";
echo "<a href=\"./about.php\">YANMAH2 について</a>";
?>
</address>
</div>
<div class="access-analyzer">
<?php
echo $access_analyzer;
?>
</div>
</body>
</html>
